==> zio-aws-lexmodelsv2_2.12-5.17.104.13-sources.jar: zio/aws/lexmodelsv2/model/AggregatedUtterancesSummary.scala <==
package zio.aws.lexmodelsv2.model
import java.time.Instant
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lexmodelsv2.model.primitives.{
  HitCount,
  Timestamp,
  BoxedBoolean,
  Utterance,
  MissedCount
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class AggregatedUtterancesSummary(
    utterance: Option[Utterance] = None,
    hitCount: Option[HitCount] = None,
    missedCount: Option[MissedCount] = None,
    utteranceFirstRecordedInAggregationDuration: Option[Timestamp] = None,
    utteranceLastRecordedInAggregationDuration: Option[Timestamp] = None,
    containsDataFromDeletedResources: Option[BoxedBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.AggregatedUtterancesSummary = {
    import AggregatedUtterancesSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.AggregatedUtterancesSummary
      .builder()
      .optionallyWith(
        utterance.map(value => Utterance.unwrap(value): java.lang.String)
      )(_.utterance)
      .optionallyWith(hitCount.map(value => HitCount.unwrap(value): Integer))(
        _.hitCount
      )
      .optionallyWith(
        missedCount.map(value => MissedCount.unwrap(value): Integer)
      )(_.missedCount)
      .optionallyWith(
        utteranceFirstRecordedInAggregationDuration.map(value =>
          Timestamp.unwrap(value): Instant
        )
      )(_.utteranceFirstRecordedInAggregationDuration)
      .optionallyWith(
        utteranceLastRecordedInAggregationDuration.map(value =>
          Timestamp.unwrap(value): Instant
        )
      )(_.utteranceLastRecordedInAggregationDuration)
      .optionallyWith(
        containsDataFromDeletedResources.map(value =>
          BoxedBoolean.unwrap(value): java.lang.Boolean
        )
      )(_.containsDataFromDeletedResources)
      .build()
  }
  def asReadOnly
      : zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary.ReadOnly =
    zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary.wrap(buildAwsValue())
}
object AggregatedUtterancesSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.AggregatedUtterancesSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary =
      zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary(
        utterance.map(value => value),
        hitCount.map(value => value),
        missedCount.map(value => value),
        utteranceFirstRecordedInAggregationDuration.map(value => value),
        utteranceLastRecordedInAggregationDuration.map(value => value),
        containsDataFromDeletedResources.map(value => value)
      )
    def utterance: Option[Utterance]
    def hitCount: Option[HitCount]
    def missedCount: Option[MissedCount]
    def utteranceFirstRecordedInAggregationDuration: Option[Timestamp]
    def utteranceLastRecordedInAggregationDuration: Option[Timestamp]
    def containsDataFromDeletedResources: Option[BoxedBoolean]
    def getUtterance: ZIO[Any, AwsError, Utterance] =
      AwsError.unwrapOptionField("utterance", utterance)
    def getHitCount: ZIO[Any, AwsError, HitCount] =
      AwsError.unwrapOptionField("hitCount", hitCount)
    def getMissedCount: ZIO[Any, AwsError, MissedCount] =
      AwsError.unwrapOptionField("missedCount", missedCount)
    def getUtteranceFirstRecordedInAggregationDuration
        : ZIO[Any, AwsError, Timestamp] = AwsError.unwrapOptionField(
      "utteranceFirstRecordedInAggregationDuration",
      utteranceFirstRecordedInAggregationDuration
    )
    def getUtteranceLastRecordedInAggregationDuration
        : ZIO[Any, AwsError, Timestamp] = AwsError.unwrapOptionField(
      "utteranceLastRecordedInAggregationDuration",
      utteranceLastRecordedInAggregationDuration
    )
    def getContainsDataFromDeletedResources: ZIO[Any, AwsError, BoxedBoolean] =
      AwsError.unwrapOptionField(
        "containsDataFromDeletedResources",
        containsDataFromDeletedResources
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.AggregatedUtterancesSummary
  ) extends zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary.ReadOnly {
    override val utterance: Option[Utterance] = scala
      .Option(impl.utterance())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Utterance(value))
    override val hitCount: Option[HitCount] = scala
      .Option(impl.hitCount())
      .map(value => zio.aws.lexmodelsv2.model.primitives.HitCount(value))
    override val missedCount: Option[MissedCount] = scala
      .Option(impl.missedCount())
      .map(value => zio.aws.lexmodelsv2.model.primitives.MissedCount(value))
    override val utteranceFirstRecordedInAggregationDuration
        : Option[Timestamp] = scala
      .Option(impl.utteranceFirstRecordedInAggregationDuration())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Timestamp(value))
    override val utteranceLastRecordedInAggregationDuration: Option[Timestamp] =
      scala
        .Option(impl.utteranceLastRecordedInAggregationDuration())
        .map(value => zio.aws.lexmodelsv2.model.primitives.Timestamp(value))
    override val containsDataFromDeletedResources: Option[BoxedBoolean] = scala
      .Option(impl.containsDataFromDeletedResources())
      .map(value => zio.aws.lexmodelsv2.model.primitives.BoxedBoolean(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.AggregatedUtterancesSummary
  ): zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lexmodelsv2_2.12-5.17.153.2-sources.jar: zio/aws/lexmodelsv2/model/AggregatedUtterancesSummary.scala <==
package zio.aws.lexmodelsv2.model
import java.time.Instant
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lexmodelsv2.model.primitives.{
  HitCount,
  Timestamp,
  BoxedBoolean,
  Utterance,
  MissedCount
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class AggregatedUtterancesSummary(
    utterance: Option[Utterance] = None,
    hitCount: Option[HitCount] = None,
    missedCount: Option[MissedCount] = None,
    utteranceFirstRecordedInAggregationDuration: Option[Timestamp] = None,
    utteranceLastRecordedInAggregationDuration: Option[Timestamp] = None,
    containsDataFromDeletedResources: Option[BoxedBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexmodelsv2.model.AggregatedUtterancesSummary = {
    import AggregatedUtterancesSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexmodelsv2.model.AggregatedUtterancesSummary
      .builder()
      .optionallyWith(
        utterance.map(value => Utterance.unwrap(value): java.lang.String)
      )(_.utterance)
      .optionallyWith(hitCount.map(value => HitCount.unwrap(value): Integer))(
        _.hitCount
      )
      .optionallyWith(
        missedCount.map(value => MissedCount.unwrap(value): Integer)
      )(_.missedCount)
      .optionallyWith(
        utteranceFirstRecordedInAggregationDuration.map(value =>
          Timestamp.unwrap(value): Instant
        )
      )(_.utteranceFirstRecordedInAggregationDuration)
      .optionallyWith(
        utteranceLastRecordedInAggregationDuration.map(value =>
          Timestamp.unwrap(value): Instant
        )
      )(_.utteranceLastRecordedInAggregationDuration)
      .optionallyWith(
        containsDataFromDeletedResources.map(value => value: java.lang.Boolean)
      )(_.containsDataFromDeletedResources)
      .build()
  }
  def asReadOnly
      : zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary.ReadOnly =
    zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary.wrap(buildAwsValue())
}
object AggregatedUtterancesSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexmodelsv2.model.AggregatedUtterancesSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary =
      zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary(
        utterance.map(value => value),
        hitCount.map(value => value),
        missedCount.map(value => value),
        utteranceFirstRecordedInAggregationDuration.map(value => value),
        utteranceLastRecordedInAggregationDuration.map(value => value),
        containsDataFromDeletedResources.map(value => value)
      )
    def utterance: Option[Utterance]
    def hitCount: Option[HitCount]
    def missedCount: Option[MissedCount]
    def utteranceFirstRecordedInAggregationDuration: Option[Timestamp]
    def utteranceLastRecordedInAggregationDuration: Option[Timestamp]
    def containsDataFromDeletedResources: Option[BoxedBoolean]
    def getUtterance: ZIO[Any, AwsError, Utterance] =
      AwsError.unwrapOptionField("utterance", utterance)
    def getHitCount: ZIO[Any, AwsError, HitCount] =
      AwsError.unwrapOptionField("hitCount", hitCount)
    def getMissedCount: ZIO[Any, AwsError, MissedCount] =
      AwsError.unwrapOptionField("missedCount", missedCount)
    def getUtteranceFirstRecordedInAggregationDuration
        : ZIO[Any, AwsError, Timestamp] = AwsError.unwrapOptionField(
      "utteranceFirstRecordedInAggregationDuration",
      utteranceFirstRecordedInAggregationDuration
    )
    def getUtteranceLastRecordedInAggregationDuration
        : ZIO[Any, AwsError, Timestamp] = AwsError.unwrapOptionField(
      "utteranceLastRecordedInAggregationDuration",
      utteranceLastRecordedInAggregationDuration
    )
    def getContainsDataFromDeletedResources: ZIO[Any, AwsError, BoxedBoolean] =
      AwsError.unwrapOptionField(
        "containsDataFromDeletedResources",
        containsDataFromDeletedResources
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.AggregatedUtterancesSummary
  ) extends zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary.ReadOnly {
    override val utterance: Option[Utterance] = scala
      .Option(impl.utterance())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Utterance(value))
    override val hitCount: Option[HitCount] = scala
      .Option(impl.hitCount())
      .map(value => zio.aws.lexmodelsv2.model.primitives.HitCount(value))
    override val missedCount: Option[MissedCount] = scala
      .Option(impl.missedCount())
      .map(value => zio.aws.lexmodelsv2.model.primitives.MissedCount(value))
    override val utteranceFirstRecordedInAggregationDuration
        : Option[Timestamp] = scala
      .Option(impl.utteranceFirstRecordedInAggregationDuration())
      .map(value => zio.aws.lexmodelsv2.model.primitives.Timestamp(value))
    override val utteranceLastRecordedInAggregationDuration: Option[Timestamp] =
      scala
        .Option(impl.utteranceLastRecordedInAggregationDuration())
        .map(value => zio.aws.lexmodelsv2.model.primitives.Timestamp(value))
    override val containsDataFromDeletedResources: Option[BoxedBoolean] = scala
      .Option(impl.containsDataFromDeletedResources())
      .map(value => value: BoxedBoolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexmodelsv2.model.AggregatedUtterancesSummary
  ): zio.aws.lexmodelsv2.model.AggregatedUtterancesSummary.ReadOnly =
    new Wrapper(impl)
}
